@@ -63,22 +63,24 @@ def gen_agg_sparse(x, index, p=1, a=0, shift=True, special=False, agg_dim=0, dim
 		if p == math.inf:
 			if torch.is_complex(x):
 				x = x.real
-			return scatter(x, index, dim=0, reduce="max")
+			return scatter(x, index, dim=agg_dim, dim_size=dim_size, reduce="max")
 		elif p == -math.inf:
 			if torch.is_complex(x):
 				x = x.real
-			return scatter(x, index, dim=0, reduce="min")
+			return scatter(x, index, dim=agg_dim, dim_size=dim_size, reduce="min")
 		elif p == 0:
 			dtype = x.dtype
 			if torch.is_complex(x):
 				x = x.real
-			N = scatter(torch.ones(x.shape[0], device=x.device), index, dim=agg_dim, dim_size=dim_size, reduce="sum")
+			N = scatter(torch.ones(x.shape[agg_dim], device=x.device), index, dim=agg_dim, dim_size=dim_size, reduce="sum")
 			prod = scatter(x, index, dim=agg_dim, dim_size=dim_size, reduce="mul")
 			Y = torch.pow(prod.cfloat(), 1/N)
 			return Y.type(dtype)
 
 	# number of neighbours
-	N = scatter(torch.ones(x.shape[0], device=x.device), index, dim=agg_dim, dim_size=dim_size, reduce="sum")
+	N = scatter(torch.ones(x.shape[agg_dim], device=x.device), index, dim=agg_dim, dim_size=dim_size, reduce="sum")
+	# Can't have divide by zero error, this should not affect final results
+	N[N==0] = 1
 
 	# when shift is True, p=0 is min, p=1 is avg, p=inf is max
 	if shift:
@@ -101,14 +103,15 @@ def logsumexp_sparse(x, index, agg_dim=0, dim_size=None):
 	torch tensors"""
 	dtype = x.dtype
 	if torch.is_complex(x):
-		c_max, _ = x.real.max(dim=0)
-		c_min, _ = x.real.min(dim=0)
+		c_max, _ = x.real.max(dim=agg_dim)
+		c_min, _ = x.real.min(dim=agg_dim)
 		x = x.cdouble()
 	else:
-		c_max, _ = x.max(dim=0)
-		c_min, _ = x.min(dim=0)
+		c_max, _ = x.max(dim=agg_dim)
+		c_min, _ = x.min(dim=agg_dim)
 		x = x.double()
 	c = (c_max + c_min) / 2
+	c.unsqueeze(agg_dim)
 	shifted = torch.exp(x - c)
 	summed = scatter(shifted, index, dim=agg_dim, dim_size=dim_size, reduce="sum")
 	res = c + torch.log(summed).type(dtype)
@@ -124,7 +127,7 @@ if __name__ == '__main__':
 	in_size = 5
 	out_size = 1
 	# Shape [nodes, node_feats]
-	x = torch.randn(in_size,2).cfloat()
+	x = torch.randn(in_size,2).cfloat() * 100
 	index = torch.randint(low=0, high=out_size, size=(in_size,))
 	p = 1.99
 	#res = gen_agg_sparse(x=x, p=p, index=index, shift=False)
